==> moodle-1.5-mysql.tgz: moodle/lang/nl/grades.php <==
<?PHP // $Id$ 
      // grades.php - created with Moodle 1.5 ALPHA (2005051500)


$string['addcategory'] = 'Voeg categorie toe';
$string['addcategoryerror'] = 'Kon geen categorie toevoegen';
$string['addexceptionerror'] = 'Fout opgetreden bij het toevoegen van een uitzondering voor userid:gradeitem';
$string['allgrades'] = 'Alle cijfers per categorie';
$string['allstudents'] = 'Alle leerlingen';
$string['average'] = 'Gemiddelde';
$string['bonuspoints'] = 'Bonuspunten';
$string['categories'] = 'Categorien';
$string['category'] = 'Categorie';
$string['choosecategory'] = 'Kies categorie';
$string['creatinggradebooksettings'] = 'Puntenboek instellingen maken';
$string['curveto'] = 'Afbuigen naar';
$string['deletecategory'] = 'Verwijder categorie';
$string['displaylettergrade'] = 'Toon een beoordeling met letters';
$string['displaypercent'] = 'Toon procent';
$string['displaypoints'] = 'Toon punten';
$string['displayweighted'] = 'Toon een gewogen cijfer';
$string['dropped'] = 'Weggelaten';
$string['dropxlowest'] = 'Laat de X laagste weg';
$string['dropxlowestwarning'] = 'Opmerking: als je \'Laat de X laagste weg\' gebruikt, dan gaat het puntenboek er van uit dat alle items in de categorie dezelfde puntenwaarde hebben. Als de puntenwaarden verschillen, dan zullen de resultaten onvoorspelbaar zijn.';
$string['errorgradevaluenonnumeric'] = 'Niet-numerieke waarde ontvangen voor laagste en hoogste cijfer voor';
$string['errornocategorizedid'] = 'Kon geen id zonder categorie vinden!';
$string['errornocourse'] = 'Kon geen informatie van het vak vinden';
$string['errorreprintheadersnonnumeric'] = 'Niet-numerieke waarde ontvangen voor koppen herhalen';
$string['exceptions'] = 'Uitzonderingen';
$string['excluded'] = 'Uitgesloten';
$string['extracredit'] = 'Extra krediet';
$string['extracreditwarning'] = 'Opmerking: als je alle items van een categorie als \'Extra krediet\' instelt, haal je ze uit de berekening van de cijfers omdat er geen puntentotaal meer is';
$string['forstudents'] = 'Voor leerlingen';
$string['gradebook'] = 'Puntenboek';
$string['gradebookhiddenerror'] = 'Het puntenboek is nu ingesteld om alles voor de leerlingen te verbergen.';
$string['gradecategoryhelp'] = 'Help bij cijfercategorien';
$string['gradeexceptions'] = 'Cijferuitzonderingen';
$string['gradeexceptionshelp'] = 'Help bij cijferuitzonderingen';
$string['gradehelp'] = 'Help bij cijfers';
$string['gradeitem'] = 'Cijferitem';
$string['gradeitemaddusers'] = 'Niet meerekenen';
$string['gradeitemmembersselected'] = 'Niet meegerekend';
$string['gradeitemnonmembers'] = 'Meegerekend';
$string['gradeitemremovemembers'] = 'Meerekenen';
$string['gradeitems'] = 'Cijferitems';
$string['gradeletter'] = 'Letterbeoordeling';
$string['gradeletterhelp'] = 'Help bij letterbeoordeling';
$string['gradeletternote'] = 'Om een letterbeoordeling te verwijderen, maak je<br /> gewoon n van de drie tekstzones voor die letter leeg en klik je op bewaren.';
$string['gradepreferenceshelp'] = 'Help bij voorkeursinstellingen';
$string['grades'] = 'Cijfers';
$string['gradeweighthelp'] = 'Help bij gewogen cijfers';
$string['hideadvanced'] = 'Verberg geavanceerde mogelijkheden';
$string['hidecategory'] = 'Verborgen';
$string['highgradeascending'] = 'Sorteer cijfers oplopend';
$string['highgradedescending'] = 'Sorteer cijfers aflopend';
$string['highgradeletter'] = 'Hoog';
$string['incorrectcourseid'] = 'Vak ID was fout';
$string['item'] = 'Item';
$string['items'] = 'Items';
$string['lettergrade'] = 'Cijferbeoordeling';
$string['lettergradenonnumber'] = 'Laagste en/of hoogste cijfer was geen cijfer';
$string['letters'] = 'Letters';
$string['lowest'] = 'Laagste';
$string['lowgradeletter'] = 'Laag';
$string['max'] = 'Hoogste';
$string['maxgrade'] = 'Maximumcijfer';
$string['median'] = 'Mediaan';
$string['min'] = 'Laagste';
$string['mode'] = 'Modus';
$string['no'] = 'Nee';
$string['nocategories'] = 'Cijfercategorien konden voor dit vak niet gevonden of toegevoegd worden';
$string['nocategoryview'] = 'Geen categorien om te tonen';
$string['nogradeletters'] = 'Geen cijferbeoordelingen ingesteld';
$string['nogradesreturned'] = 'Geen cijfers';
$string['nolettergrade'] = 'Geen letterbeoordeling voor';
$string['nomode'] = 'NA';
$string['nonnumericweight'] = 'Een niet-numerieke waarde ontvangen voor';
$string['nonweightedpct'] = '%% zonder weging';
$string['pctoftotalgrade'] = '%% van totaalcijfer';
$string['percent'] = 'Procent';
$string['percentascending'] = 'Sorteer procent oplopend';
$string['percentdescending'] = 'Sorteer procent aflopend';
$string['percentshort'] = '%%';
$string['points'] = 'punten';
$string['pointsascending'] = 'Sorteer punten oplopend';
$string['pointsdescending'] = 'Sorteer punten aflopend';
$string['preferences'] = 'Voorkeuren';
$string['rawpct'] = 'Ruw %%';
$string['reprintheaders'] = 'Koppen herhalen';
$string['savechanges'] = 'Bewaar wijzigingen';
$string['savepreferences'] = 'Bewaar instellingen';
$string['scaledpct'] = 'Procentuele schaal';
$string['setcategories'] = 'Maak categorien';
$string['setcategorieserror'] = 'Je moet eerst de categorien voor je vak instellen voor je er wegingen kan aan geven.';
$string['setgradeletters'] = 'Maak cijferbeoordeling';
$string['setpreferences'] = 'Kies instellingen';
$string['setting'] = 'Instelling';
$string['settings'] = 'Instellingen';
$string['setweights'] = 'Kies wegingen';
$string['showallstudents'] = 'Toon alle leerlingen';
$string['showhiddenitems'] = 'Toon verborgen items';
$string['sort'] = 'Sorteer';
$string['sortbyfirstname'] = 'Sorteer op voornaam';
$string['sortbylastname'] = 'Sorteer op achternaam';
$string['standarddeviation'] = 'Standaarddeviatie';
$string['stats'] = 'Statistieken';
$string['statslink'] = 'Statistieken';
$string['student'] = 'Leerling';
$string['total'] = 'Totaal';
$string['totalweight100'] = 'Het totaalgewicht is 100';
$string['totalweightnot100'] = 'Het totaalgewicht is verschillend van 100';
$string['uncategorised'] = 'Zonder categorie';
$string['useadvanced'] = 'Gebruik geavanceerde mogelijkheden';
$string['usepercent'] = 'Gebruik procent';
$string['useweighted'] = 'Gebruik weging';
$string['viewbygroup'] = 'Groep';
$string['viewgrades'] = 'Bekijk cijfers';
$string['weight'] = 'weging';
$string['weightedascending'] = 'Sorteer oplopend gewogen procent';
$string['weighteddescending'] = 'Sorteer aflopend gewogen procent';
$string['weightedpct'] = 'gewogen %%';
$string['weightedpctcontribution'] = 'gewogen %% bijdrage';
$string['writinggradebookinfo'] = 'Instelling puntenboek wegschrijven';
$string['yes'] = 'Ja';

?>

==> moodle-1.5.3-mysql.tgz: moodle/lang/nl/grades.php <==
<?PHP // $Id$ 
      // grades.php - created with Moodle 1.5 ALPHA (2005051500)


$string['addcategory'] = 'Voeg categorie toe';
$string['addcategoryerror'] = 'Kon geen categorie toevoegen';
$string['addexceptionerror'] = 'Fout opgetreden bij het toevoegen van een uitzondering voor userid:gradeitem';
$string['allgrades'] = 'Alle cijfers per categorie';
$string['allstudents'] = 'Alle leerlingen';
$string['average'] = 'Gemiddelde';
$string['bonuspoints'] = 'Bonuspunten';
$string['categories'] = 'Categorien';
$string['category'] = 'Categorie';
$string['choosecategory'] = 'Kies categorie';
$string['creatinggradebooksettings'] = 'Instellingen puntenboek maken';
$string['curveto'] = 'Afbuigen naar';
$string['deletecategory'] = 'Verwijder categorie';
$string['displaylettergrade'] = 'Toon een beoordeling met letters';
$string['displaypercent'] = 'Toon procent';
$string['displaypoints'] = 'Toon punten';
$string['displayweighted'] = 'Toon een gewogen cijfer';
$string['dropped'] = 'Weggelaten';
$string['dropxlowest'] = 'Laat de X laagste weg';
$string['dropxlowestwarning'] = 'Opmerking: als je \'Laat de X laagste weg\' gebruikt, dan gaat het puntenboek er van uit dat alle items in de categorie dezelfde puntenwaarde hebben. Als de puntenwaarden verschillen, dan zullen de resultaten onvoorspelbaar zijn.';
$string['errorgradevaluenonnumeric'] = 'Niet-numerieke waarde ontvangen voor laagste en hoogste cijfer voor';
$string['errornocategorizedid'] = 'Kon geen id zonder categorie vinden!';
$string['errornocourse'] = 'Kon geen informatie over de cursus vinden';
$string['errorreprintheadersnonnumeric'] = 'Niet-numerieke waarde ontvangen voor koppen herhalen';
$string['exceptions'] = 'Uitzonderingen';
$string['excluded'] = 'Uitgesloten';
$string['extracredit'] = 'Extra krediet';
$string['extracreditwarning'] = 'Opmerking: als je alle items van een categorie als \'Extra krediet\' instelt, haal je ze uit de berekening van de cijfers omdat er geen puntentotaal meer is';
$string['forstudents'] = 'Voor leerlingen';
$string['gradebook'] = 'Puntenboek';
$string['gradebookhiddenerror'] = 'Het puntenboek is nu ingesteld om alles voor de leerlingen te verbergen.';
$string['gradecategoryhelp'] = 'Help bij cijfercategorien';
$string['gradeexceptions'] = 'Cijferuitzonderingen';
$string['gradeexceptionshelp'] = 'Help bij cijferuitzonderingen';
$string['gradehelp'] = 'Help bij cijfers';
$string['gradeitem'] = 'Cijferitem';
$string['gradeitemaddusers'] = 'Niet meerekenen';
$string['gradeitemmembersselected'] = 'Niet meegerekend';
$string['gradeitemnonmembers'] = 'Meegerekend';
$string['gradeitemremovemembers'] = 'Meerekenen';
$string['gradeitems'] = 'Cijferitems';
$string['gradeletter'] = 'Letterbeoordeling';
$string['gradeletterhelp'] = 'Help bij letterbeoordeling';
$string['gradeletternote'] = 'Om een letterbeoordeling te verwijderen, maak je<br /> gewoon n van de drie tekstzones voor die letter leeg en klik je op bewaren.';
$string['gradepreferenceshelp'] = 'Help bij voorkeursinstellingen';
$string['grades'] = 'Cijfers';
$string['gradeweighthelp'] = 'Help bij gewogen cijfers';
$string['hideadvanced'] = 'Verberg geavanceerde mogelijkheden';
$string['hidecategory'] = 'Verborgen';
$string['highgradeascending'] = 'Sorteer cijfers oplopend';
$string['highgradedescending'] = 'Sorteer cijfers aflopend';
$string['highgradeletter'] = 'Hoog';
$string['incorrectcourseid'] = 'Cursus ID was fout';
$string['item'] = 'Item';
$string['items'] = 'Items';
$string['lettergrade'] = 'Letterbeoordeling';
$string['lettergradenonnumber'] = 'Laagste en/of hoogste cijfer was geen cijfer';
$string['letters'] = 'Letters';
$string['lowest'] = 'Laagste';
$string['lowgradeletter'] = 'Laag';
$string['max'] = 'Hoogste';
$string['maxgrade'] = 'Maximumcijfer';
$string['median'] = 'Mediaan';
$string['min'] = 'Laagste';
$string['mode'] = 'Modus';
$string['no'] = 'Nee';
$string['nocategories'] = 'Cijfercategorien konden voor deze cursus niet gevonden of toegevoegd worden';
$string['nocategoryview'] = 'Geen categorien om te tonen';
$string['nogradeletters'] = 'Geen cijferbeoordelingen ingesteld';
$string['nogradesreturned'] = 'Geen cijfers';
$string['nolettergrade'] = 'Geen letterbeoordeling voor';
$string['nomode'] = 'NA';
$string['nonnumericweight'] = 'Een niet-numerieke waarde ontvangen voor';
$string['nonweightedpct'] = '%% zonder weging';
$string['pctoftotalgrade'] = '%% van totaalcijfer';
$string['percent'] = 'Procent';
$string['percentascending'] = 'Sorteer procent oplopend';
$string['percentdescending'] = 'Sorteer procent aflopend';
$string['percentshort'] = '%%';
$string['points'] = 'punten';
$string['pointsascending'] = 'Sorteer punten oplopend';
$string['pointsdescending'] = 'Sorteer punten aflopend';
$string['preferences'] = 'Voorkeuren';
$string['rawpct'] = 'Ruw %%';
$string['reprintheaders'] = 'Koppen herhalen';
$string['savechanges'] = 'Bewaar wijzigingen';
$string['savepreferences'] = 'Bewaar instellingen';
$string['scaledpct'] = 'Procentuele schaal';
$string['setcategories'] = 'Categorien';
$string['setcategorieserror'] = 'Je moet eerst de categorien voor je cursus instellen voor je er wegingen kan aan geven.';
$string['setgradeletters'] = 'Letterbeoordeling';
$string['setpreferences'] = 'Instellingen';
$string['setting'] = 'Instelling';
$string['settings'] = 'Instellingen';
$string['setweights'] = 'Wegingen';
$string['showallstudents'] = 'Toon alle leerlingen';
$string['showhiddenitems'] = 'Toon verborgen items';
$string['sort'] = 'Sorteer';
$string['sortbyfirstname'] = 'Sorteer op voornaam';
$string['sortbylastname'] = 'Sorteer op achternaam';
$string['standarddeviation'] = 'Standaarddeviatie';
$string['stats'] = 'Statistieken';
$string['statslink'] = 'Statistieken';
$string['student'] = 'Leerling';
$string['total'] = 'Totaal';
$string['totalweight100'] = 'Het totaalgewicht is 100';
$string['totalweightnot100'] = 'Het totaalgewicht is verschillend van 100';
$string['uncategorised'] = 'Zonder categorie';
$string['useadvanced'] = 'Gebruik geavanceerde mogelijkheden';
$string['usepercent'] = 'Gebruik procent';
$string['useweighted'] = 'Gebruik weging';
$string['viewbygroup'] = 'Groep';
$string['viewgrades'] = 'Bekijk cijfers';
$string['weight'] = 'weging';
$string['weightedascending'] = 'Sorteer oplopend gewogen procent';
$string['weighteddescending'] = 'Sorteer aflopend gewogen procent';
$string['weightedpct'] = 'gewogen %%';
$string['weightedpctcontribution'] = 'gewogen %% bijdrage';
$string['writinggradebookinfo'] = 'Instelling puntenboek wegschrijven';
$string['yes'] = 'Ja';

?>
